#
# spec file for package python-marathon
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-marathon
Version:        0.13.0
Release:        3.2
Summary:        Marathon Client Library
License:        MIT
URL:            https://github.com/thefactory/marathon-python
Source:         https://github.com/thefactory/marathon-python/archive/refs/tags/%{version}.tar.gz#/marathon-%{version}.tar.gz
# https://github.com/thefactory/marathon-python/issues/284
Patch0:         python-marathon-no-2to3.patch
# https://github.com/thefactory/marathon-python/commit/1850734b5b916d1455416833f0aed239b308dd9f.diff
Patch1:         python-marathon-use-collections.abc.patch
Patch2:         fix-assertion-method.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests-toolbelt}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.4.0
Requires:       python-requests-toolbelt >= 0.4.0
BuildArch:      noarch
%python_subpackages

%description
Python interface to the Mesos Marathon REST API.

%prep
%autosetup -p1 -n marathon-python-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%{python_sitelib}/marathon
%{python_sitelib}/marathon-%{version}.dist-info

%changelog
* Wed Jan 24 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Stop using greedy globs in %%files.
- Actually run fdupes.
- Add patch fix-assertion-method.patch:
  * Use assertEqual, not assertEquals.
* Mon Feb 28 2022 pgajdos@suse.com
- fix build, run tests
- added patches
  fix https://github.com/thefactory/marathon-python/issues/284
  + python-marathon-no-2to3.patch
  fix https://github.com/thefactory/marathon-python/commit/1850734b5b916d1455416833f0aed239b308dd9f.diff
  + python-marathon-use-collections.abc.patch
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.13.0:
  - about view one instance app logs real time
  - Fix deserialization for Deploment model
  - Local tests no longer need docker-compose and rely on "mini-marathon"
  - Adding support for v1.10.19
  - Updates for Marathon 1.9.109
  - Fix return value for kill\_given\_tasks.
  - Bump requests from 2.11.1 to 2.20.0
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 0.12.0
    Downloading Log For App #265
    Always create TZ-aware datetime objects. (also drop support for python 2) #267 (EvanKrall)
    Compatible with event stream redirect behavior. #262 (fengyehong)
* Wed Mar 27 2019 pgajdos@suse.com
- version update to 0.11.0
  * Added region and zone members to task model. #260
  * Exception #259
  * SSE SSL authentication not supported #247
  * Lack of support for container.networks #243
  * __init__() got an unexpected keyword argument 'port_mappings' #237
  * Wrong health check object generated for COMMAND protocol #222
  * Add support for mesos 1.6 #255
  * Possibility for send the full json object on create #252
  * events: add a few attributes #251
  * install-marathon.sh: do not remove oracle-java7-installer #250
  * MarathonClient: set verify when using sse_session #248
  * add reset delay api #246
  * fixes for issue 244 #245
  * Test against 1.4.11 #240
  * fix isuuse-238 #239 (yudong2015)
  * Test against 1.4.10 instead of 1.4.9 #236
  * make models.info compatible with 1.4.9 #233
  * Fix health check 'command' #231
  * Feature/marathon constraint model improvements #229
  * Removes id validation from MarathonGroup() #228
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  2 2018 tchvatal@suse.com
- Fix requires
* Thu Jul 13 2017 tbechtold@suse.com
- Initial packaging (version 0.9.0)
